@@ -40,7 +40,9 @@ bool Document_XML::load_after()
   if(!bTest)
     return false; //Failed.
 
+#ifdef LIBXMLPP_EXCEPTIONS_ENABLED
   try
+#endif
   {
     //Link the parser to the XML text that was loaded:
     //m_DOM_Parser.setDoValidation(true);
@@ -50,15 +52,18 @@ bool Document_XML::load_after()
 
     m_DOM_Parser.parse_memory(m_strContents);
     m_pDOM_Document = m_DOM_Parser.get_document();
+    if(!m_pDOM_Document) return false;
 
     return true; //Success.
   }
+#ifdef LIBXMLPP_EXCEPTIONS_ENABLED
   catch(const std::exception& ex)
   {
     std::cerr << "XML Parser error: \n" << ex.what() << std::endl;
 
     return false; //Failed.
   }
+#endif
 }
 
 
@@ -82,25 +87,30 @@ bool Document_XML::save_before()
 
 bool Document_XML::set_xml(const Glib::ustring& strXML)
 { 
+#ifdef LIBXMLPP_EXCEPTIONS_ENABLED
   try
+#endif
   {
     if(m_strContents.empty())
       g_warning("Document_XML::set_xml(): parsing empty document.");
 
     m_DOM_Parser.parse_memory(m_strContents);
     m_pDOM_Document = m_DOM_Parser.get_document();
+    if(!m_pDOM_Document) return false;
 
     return true;	
   }
+#ifdef LIBXMLPP_EXCEPTIONS_ENABLED
   catch(const std::exception& ex)
   {
     std::cerr << "XML Parser error: \n" << ex.what() << std::endl;
     return false; //Failed.
   }
+#endif
 } 
 
 
-Glib::ustring Document_XML::get_xml()
+Glib::ustring Document_XML::get_xml() const
 {
   //Write XML to string:
   Glib::ustring strXML;
@@ -108,19 +118,23 @@ Glib::ustring Document_XML::get_xml()
   return strXML;
 }
 
-void Document_XML::Util_DOM_Write(Glib::ustring& refstrXML)
+void Document_XML::Util_DOM_Write(Glib::ustring& refstrXML) const
 {
+#ifdef LIBXMLPP_EXCEPTIONS_ENABLED
   try
+#endif
   {
     if(m_write_formatted)
       refstrXML = m_pDOM_Document->write_to_string_formatted();
     else
       refstrXML = m_pDOM_Document->write_to_string();
   }
+#ifdef LIBXMLPP_EXCEPTIONS_ENABLED
   catch(xmlpp::exception& ex)
   {
     std::cerr << "Document_XML::Util_DOM_Write(): exception caught: " << ex.what() << std::endl;
   }
+#endif
 }
 
 Glib::ustring Document_XML::get_node_attribute_value(const xmlpp::Element* node, const Glib::ustring& strAttributeName)
@@ -153,7 +167,7 @@ void Document_XML::set_node_attribute_value(xmlpp::Element* node, const Glib::us
   }
 }
 
-xmlpp::Element* Document_XML::get_node_child_named(const xmlpp::Element* node, const Glib::ustring& strName)const
+xmlpp::Element* Document_XML::get_node_child_named(const xmlpp::Element* node, const Glib::ustring& strName)
 {
   xmlpp::Element* nodeResult = 0;
 
@@ -225,4 +239,67 @@ void Document_XML::set_write_formatted(bool formatted)
 }
 
 
+void Document_XML::add_indenting_white_space_to_node(xmlpp::Node* node, const Glib::ustring& start_indent)
+{
+  if(!node)
+    node = get_node_document();
+
+  //Remove any previous indenting:
+  {
+  xmlpp::Node::NodeList list = node->get_children();
+  for(xmlpp::Node::NodeList::iterator iter = list.begin(); iter != list.end(); ++iter)
+  {
+    xmlpp::Node* child = *iter;
+    if(!child)
+      continue;
+
+    xmlpp::ContentNode* text = dynamic_cast<xmlpp::ContentNode*>(child);
+    if(text)
+    {
+      if(text->is_white_space())
+        node->remove_child(text);
+    }
+  }
+  }
+
+  //All indents have a newline, 
+  //and we add spaces each time we recurse:
+  Glib::ustring indent = start_indent;
+  if(indent.empty())
+    indent = "\n  ";
+  else
+    indent += "  ";
+
+  //Add indenting text items:
+  bool had_children = false;
+  xmlpp::Element* node_as_element = dynamic_cast<xmlpp::Element*>(node);
+  xmlpp::Node::NodeList list = node_as_element->get_children();
+  for(xmlpp::Node::NodeList::iterator iter = list.begin(); iter != list.end(); ++iter)
+  {
+    xmlpp::Node* child = *iter;
+    if(!child)
+      continue;
+
+    xmlpp::ContentNode* text = dynamic_cast<xmlpp::ContentNode*>(child);
+    if(text)
+    {
+      if(!text->is_white_space())
+        continue; //Don't change content items.
+    }
+
+    //Add a text item for the indenting, before the child:
+    //std::cout << "  Adding indent after node=" << child->get_name() << ": START" << indent << "END" << std::endl;
+    node_as_element->add_child_text_before(child, indent);
+    had_children = true;
+
+    //Recurse into the children:
+    add_indenting_white_space_to_node(child, indent);
+  }
+
+  //If it has children then add an indent before the closing tag:
+  if(had_children)
+    node_as_element->add_child_text(start_indent);
+}
+
+
 } //namespace Bakery.
